==> aliyun-java-sdk-vpc-3.1.12-sources.jar: com/aliyuncs/vpc/transform/v20160428/UpdateVirtualBorderBandwidthResponseUnmarshaller.java <==
/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.aliyuncs.vpc.transform.v20160428;

import com.aliyuncs.vpc.model.v20160428.UpdateVirtualBorderBandwidthResponse;
import com.aliyuncs.transform.UnmarshallerContext;


public class UpdateVirtualBorderBandwidthResponseUnmarshaller {

	public static UpdateVirtualBorderBandwidthResponse unmarshall(UpdateVirtualBorderBandwidthResponse updateVirtualBorderBandwidthResponse, UnmarshallerContext _ctx) {
		
		updateVirtualBorderBandwidthResponse.setRequestId(_ctx.stringValue("UpdateVirtualBorderBandwidthResponse.RequestId"));
		updateVirtualBorderBandwidthResponse.setSuccess(_ctx.booleanValue("UpdateVirtualBorderBandwidthResponse.Success"));
		updateVirtualBorderBandwidthResponse.setHttpStatusCode(_ctx.stringValue("UpdateVirtualBorderBandwidthResponse.HttpStatusCode"));
		updateVirtualBorderBandwidthResponse.setMessage(_ctx.stringValue("UpdateVirtualBorderBandwidthResponse.Message"));
		updateVirtualBorderBandwidthResponse.setCode(_ctx.stringValue("UpdateVirtualBorderBandwidthResponse.Code"));
	 
	 	return updateVirtualBorderBandwidthResponse;
	}
}

==> aliyun-java-sdk-vpc-3.2.10-sources.jar: com/aliyuncs/vpc/transform/v20160428/UpdateVirtualBorderBandwidthResponseUnmarshaller.java <==
/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.aliyuncs.vpc.transform.v20160428;

import com.aliyuncs.vpc.model.v20160428.UpdateVirtualBorderBandwidthResponse;
import com.aliyuncs.transform.UnmarshallerContext;


public class UpdateVirtualBorderBandwidthResponseUnmarshaller {

	public static UpdateVirtualBorderBandwidthResponse unmarshall(UpdateVirtualBorderBandwidthResponse updateVirtualBorderBandwidthResponse, UnmarshallerContext _ctx) {
		
		updateVirtualBorderBandwidthResponse.setRequestId(_ctx.stringValue("UpdateVirtualBorderBandwidthResponse.RequestId"));
		updateVirtualBorderBandwidthResponse.setCode(_ctx.stringValue("UpdateVirtualBorderBandwidthResponse.Code"));
		updateVirtualBorderBandwidthResponse.setHttpStatusCode(_ctx.integerValue("UpdateVirtualBorderBandwidthResponse.HttpStatusCode"));
		updateVirtualBorderBandwidthResponse.setMessage(_ctx.stringValue("UpdateVirtualBorderBandwidthResponse.Message"));
		updateVirtualBorderBandwidthResponse.setSuccess(_ctx.booleanValue("UpdateVirtualBorderBandwidthResponse.Success"));
	 
	 	return updateVirtualBorderBandwidthResponse;
	}
}
